@@ -1,4 +1,4 @@
-/* Stereograph 0.14, 04/04/2000;
+/* Stereograph 0.15, 10/04/2000;
  * Copyright (c) 2000 by Fabian Januszewski <fabian.linux@januszewski.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -36,18 +36,19 @@ struct GFX_DATA *pBase, *pTexture, *pStereo;
 
 void print_info(void) {
 	printf("SYNOPSIS\n  stereograph [OPTIONS] -b [FILENAME] -t [FILENAME] -o [FILENAME]\n\n");
-	printf("OPTIONS\n  -a anti-aliasing     -z zoom               (quality)\n  -d distance          -e eye shift          (perspective)\n  -x texture insert x  -y texture insert y   (layout)\n\n");
+	printf("OPTIONS\n  -a anti-aliasing     -z zoom               (quality)\n  -d distance          -e eye shift          (perspective)\n  -x texture insert x  -y texture insert y   (layout)\n  -r this flag enables anti-artefact feature (experimental)\n\n");
 }
 
 int main (int argc, char **argv) {
 
 	int last_error = 0;
-	printf("Stereograph for linux Version %s\n(c) 2000 Fabian Januszewski\n\n", "0.14");
+	printf("Stereograph for linux Version %s\n(c) 2000 Fabian Januszewski\n\n", "0.15");
 
 	Get_GFX_Pointers(&pParam, &pBase, &pTexture, &pStereo);
 
 	pParam->Zoom = 1;
 	pParam->AA = 4;
+	pParam->AAr = 0;
 	pParam->Startx = 0;
 	pParam->Starty = 0;
 	pParam->Front = 1.0;
@@ -75,6 +76,8 @@ int main (int argc, char **argv) {
 					int y, s;
 					printf("success;\n");
 					printf("using parametres as follows (zadexy): %i %i %f %f %i %i;\n", pParam->Zoom, pParam->AA, pParam->Distance, pParam->Eyeshift, pParam->Startx, pParam->Starty);
+					if(pParam->AAr)
+						printf("experimental anti-artefacts feature enabled;\n");
 					printf("processing...");
 
 					for(y = 0, s = 0; y < pBase->Height; y++) {
@@ -151,6 +154,9 @@ int parse_args (int argc, char **argv) {
 				case 'z' :
 					pParam->Zoom = atoi(argv[++z]);
 					break;
+				case 'r' :
+					pParam->AAr = 1;
+					break;
 				printf("invalid argument '%c';\n", argv[z][1]);
 				return -1;
 			}
